##  Overview
Integration API offers a wide range of functionality. Expanding scope of Integration possibilities with SAP LeanIX. Here is a collection of some suggested best practices and tips to optimize usage of Integration API.
To get access to the Integration API, navigate to the Integration API section in the admin area.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747dda87a441014b248b7827b036033_LowRes.png)
Integration API Section in the Admin Area
